@@ -9,7 +9,7 @@ required_conan_version = ">=1.50"
 
 class WaveletBufferConan(ConanFile):
     name = "wavelet_buffer"
-    version = "0.2.0"
+    version = "0.3.0"
     license = "MPL-2.0"
     author = "PANDA GmbH"
     description = "An universal C++ compression library based on wavelet transformation"
@@ -32,14 +32,18 @@ class WaveletBufferConan(ConanFile):
         if self.settings.os == "Windows":
             del self.options.fPIC
 
+        self.settings.build_type = "Release"
+
     def source(self):
         local_source = os.getenv("CONAN_SOURCE_DIR")
         if local_source is not None:
+            print(f"Use local sources: {local_source}")
             self.run(
-                "cp {} -r {}".format(os.getenv("CONAN_SOURCE_DIR"), self.source_folder)
+                "cp -r {}/. {}/".format(os.getenv("CONAN_SOURCE_DIR"), self.source_folder)
             )
         else:
             branch = f"v{self.version}" if self.channel == "stable" else self.channel
+            print(f"Use remote sources, branch: {branch}")
             git = Git()
             git.clone(
                 "https://github.com/panda-official/WaveletBuffer.git",
@@ -52,6 +56,7 @@ class WaveletBufferConan(ConanFile):
 
     def generate(self):
         tc = CMakeToolchain(self)
+        tc.variables["CONAN_EXPORTED"] = True
         tc.generate()
 
     def build(self):
